@@ -80,31 +80,39 @@ def constant_time_compare(a, b):
 
 # Event formatting - public api:
 def format_event(eventid, eventtype, eventinfo):
-    f = _formatters.get(eventtype, _format_unknown_event)
-    alw = _AttrLookupWrapper(eventinfo)
-    unistr = f(eventid, eventtype, alw)
-    return unistr.encode('utf8') # BUG: Is this acceptable for IRC?
+    f = _formatters.get(eventtype)
+    if f is None:
+        return None
+    else:
+        alw = _AttrLookupWrapper(eventinfo)
+        result = f(eventid, eventtype, alw)
+
+        if result is None:
+            return result
+        else:
+            return result.encode('utf8') # BUG: Is this acceptable for IRC?
 
 
 # Event formatting - innards:
-def _format_unknown_event(eid, etype, _einfo):
-    return 'No formatter for github event type %r with id %r.' % (etype, eid)
-
-
 _formatters = FunctionTable('_format_')
 
 
+@_formatters.register
+def _format_ping(_eid, _etype, _einfo):
+    return None
+
+
 @_formatters.register
 def _format_push(_eid, _etype, einfo):
     return '\n'.join([
-        '%(PUSHER)r pushed %(COMMITCOUNT)r commits to %(REF)r of %(REPOURL)r',
+        '%(PUSHER)r pushed %(COMMITCOUNT)r commits to %(REF)r of %(REPOURL)s',
         'Push diff: %(DIFFURL)s',
         ]) % dict(
-        PUSHER      = einfo.pusher.email,
+        PUSHER      = einfo.pusher.name,
         COMMITCOUNT = len(einfo.commits),
         REF         = einfo.ref,
         REPOURL     = einfo.repository.url,
-        DIFFURL     = einfo.compare,
+        DIFFURL     = einfo.compare.replace('^', '%5E'),
         )
 
 
